@@ -1,4 +1,6 @@
 import asyncio
+import sys
+import warnings
 
 import psycopg2
 from psycopg2.extensions import (
@@ -11,18 +13,19 @@ from .cursor import Cursor
 __all__ = ('connect',)
 
 
-TIMEOUT = 60.
+TIMEOUT = 60.0
+PY_34 = sys.version_info >= (3, 4)
 
 
 @asyncio.coroutine
 def _enable_hstore(conn):
     cur = yield from conn.cursor()
     yield from cur.execute("""\
-SELECT t.oid, typarray
-FROM pg_type t JOIN pg_namespace ns
-    ON typnamespace = ns.oid
-WHERE typname = 'hstore';
-""")
+        SELECT t.oid, typarray
+        FROM pg_type t JOIN pg_namespace ns
+            ON typnamespace = ns.oid
+        WHERE typname = 'hstore';
+        """)
     rv0, rv1 = [], []
     for oids in (yield from cur.fetchall()):
         rv0.append(oids[0])
@@ -48,7 +51,11 @@ def connect(dsn=None, *, timeout=TIMEOUT, loop=None,
 
     waiter = asyncio.Future(loop=loop)
     conn = Connection(dsn, loop, timeout, waiter, bool(echo), **kwargs)
-    yield from conn._poll(waiter, timeout)
+    try:
+        yield from conn._poll(waiter, timeout)
+    except Exception:
+        conn.close()
+        raise
     if enable_json:
         extras.register_default_json(conn._conn)
     if enable_hstore:
@@ -387,3 +394,10 @@ class Connection:
     def echo(self):
         """Return echo mode status."""
         return self._echo
+
+    if PY_34:  # pragma: no branch
+        def __del__(self):
+            if not self._conn.closed:
+                warnings.warn("Unclosed connection {!r}".format(self),
+                              ResourceWarning)
+                self.close()
