@@ -1,4 +1,5 @@
 import asyncio
+import warnings
 
 import psycopg2
 
@@ -362,8 +363,12 @@ class Cursor:
         return self._timeout
 
     def __iter__(self):
-        item = yield from self.fetchone()
-        if item is None:
-            raise StopIteration
-        else:
-            return item
+        warnings.warn("Iteration over cursor is deprecated",
+                      DeprecationWarning,
+                      stacklevel=2)
+        while True:
+            row = yield from self.fetchone()
+            if row is None:
+                raise StopIteration
+            else:
+                yield row
