@@ -1,5 +1,7 @@
 import asyncio
 import collections
+import sys
+import warnings
 
 
 from psycopg2.extensions import TRANSACTION_STATUS_IDLE
@@ -8,6 +10,9 @@ from .connection import connect, TIMEOUT
 from .log import logger
 
 
+PY_34 = sys.version_info >= (3, 4)
+
+
 @asyncio.coroutine
 def create_pool(dsn=None, *, minsize=10, maxsize=10,
                 loop=None, timeout=TIMEOUT,
@@ -245,6 +250,22 @@ class Pool(asyncio.AbstractServer):
         conn = yield from self.acquire()
         return _ConnectionContextManager(self, conn)
 
+    if PY_34:  # pragma: no branch
+        def __del__(self):
+            try:
+                self._free
+            except AttributeError:
+                return  # frame has been cleared, __dict__ is empty
+            if self._free:
+                left = 0
+                while self._free:
+                    conn = self._free.popleft()
+                    conn.close()
+                    left += 1
+                warnings.warn(
+                    "Unclosed {} connections in {!r}".format(left, self),
+                    ResourceWarning)
+
 
 class _ConnectionContextManager:
     """Context manager.
