@@ -1,16 +1,17 @@
+import asyncio
+import json
+
+import aiopg
+from .connection import SAConnection
+from .exc import InvalidRequestError
+from aiopg.connection import TIMEOUT
+
+
 try:
     from sqlalchemy.dialects.postgresql.psycopg2 import PGDialect_psycopg2
 except ImportError:  # pragma: no cover
     raise ImportError('aiopg.sa requires sqlalchemy')
 
-import asyncio
-import aiopg
-import json
-
-from .connection import SAConnection
-from .exc import InvalidRequestError
-from aiopg.connection import TIMEOUT
-
 
 _dialect = PGDialect_psycopg2(json_serializer=json.dumps,
                               json_deserializer=lambda x: x)
@@ -123,7 +124,7 @@ class Engine:
     def acquire(self):
         """Get a connection from pool."""
         raw = yield from self._pool.acquire()
-        conn = SAConnection(raw, self._dialect)
+        conn = SAConnection(raw, self)
         return conn
 
     def release(self, conn):
